/**
* Checks the contents of the new video comment and decides whether or not to allow it through
*
* @param	object	<form> object containing quick video comment
* @param	integer	Minimum allowed characters in message
*
* @return	boolean
*/
function qr_prepare_video_comment_submit(formobj, minchars)
{
	if (qr_repost == true)
	{
		return true;
	}

	allow_ajax_qr = false;

	if (!allow_ajax_qr || !AJAX_Compatible)
	{
		// not last page, or threaded mode - do not attempt to use AJAX
		return qr_check_data(formobj, minchars);
	}
	else if (qr_check_data(formobj, minchars))
	{
		if (typeof vb_disable_ajax != 'undefined' && vb_disable_ajax > 0)
		{
			// couldn't initialize, return true to allow click to go through
			return true;
		}

		if (is_ie && userAgent.indexOf('msie 5.') != -1)
		{
			// IE 5 has problems with non-ASCII characters being returned by
			// AJAX. Don't universally disable it, but if we're going to be sending
			// non-ASCII, let's not use AJAX.
			if (PHP.urlencode(formobj.message.value).indexOf('%u') != -1)
			{
				return true;
			}
		}

		if (YAHOO.util.Connect.isCallInProgress(qr_ajax))
		{
			return false;
		}

		//Construct Submit String
		var submitstring = 'ajax=1';
		if (typeof ajax_last_post != 'undefined')
		{
			submitstring += '&ajax_lastpost=' + PHP.urlencode(ajax_last_post);
		}

		for (var i = 0; i < formobj.elements.length; i++)
		{
			var obj = formobj.elements[i];

			if (obj.name && !obj.disabled)
			{
				switch (obj.type)
				{
					case 'text':
					case 'textarea':
					case 'hidden':
						submitstring += '&' + obj.name + '=' + PHP.urlencode(obj.value);
						break;
					case 'checkbox':
					case 'radio':
						submitstring += obj.checked ? '&' + obj.name + '=' + PHP.urlencode(obj.value) : '';
						break;
					case 'select-one':
						submitstring += '&' + obj.name + '=' + PHP.urlencode(obj.options[obj.selectedIndex].value);
						break;
					case 'select-multiple':
						for (var j = 0; j < obj.options.length; j++)
						{
							submitstring += (obj.options[j].selected ? '&' + obj.name + '=' + PHP.urlencode(obj.options[j].value) : '');
						}
						break;
				}
			}
		}

		document.body.style.cursor = 'wait';

		qr_ajax_comment(formobj.action, submitstring);
		return false;
	}
	else
	{
		return false;
	}
}

/**
* Sends video comment data to video.php via AJAX
*
* @param	string	GET string for action (video.php)
* @param	string	String representing form data ('x=1&y=2&z=3' etc.)
*/
function qr_ajax_comment(submitaction, submitstring)
{
	if (YAHOO.util.Connect.isCallInProgress(qr_ajax))
	{
		YAHOO.util.Connect.abort(qr_ajax);
	}

	qr_repost = false;

	qr_ajax = YAHOO.util.Connect.asyncRequest("POST", submitaction, {
		success: qr_do_ajax_comment,
		failure: qr_handle_error,
		timeout: vB_Default_Timeout
	}, SESSIONURL + "securitytoken=" + SECURITYTOKEN + '&' + submitstring);
}

/**
* Handles quick reply data when AJAX says qr_ajax_comment() is complete
*
* @param	object	YUI AJAX
*/
function qr_do_ajax_comment(ajax)
{
	if (ajax.responseXML)
	{
		document.body.style.cursor = 'auto';
		var i;

		if (fetch_tag_count(ajax.responseXML, 'postbit'))
		{
			ajax_last_post = ajax.responseXML.getElementsByTagName('time')[0].firstChild.nodeValue;
			qr_disable_controls();
			qr_hide_errors();

			var postbits = ajax.responseXML.getElementsByTagName('postbit');
			for (i = 0; i < postbits.length; i++)
			{
				var newdiv = document.createElement('div');
				newdiv.innerHTML = postbits[i].firstChild.nodeValue;
				var lp = fetch_object('lastpost');
				var lpparent = lp.parentNode;
				var postbit = lpparent.insertBefore(newdiv, lp);

				PostBit_Init(postbit, postbits[i].getAttribute('postid'));
			}

			// unfocus the qr_submit button to prevent a space from resubmitting
			if (fetch_object('qr_submit'))
			{
				fetch_object('qr_submit').blur();
			}
		}
		else
		{
			if (!is_saf)
			{
				// this is the nice error handler, of which Safari makes a mess
				var errors = ajax.responseXML.getElementsByTagName('error');

				if (errors[0].firstChild.nodeValue == 'hv_check')
				{
					qr_repost = true;
					fetch_object('qrform').submit();

					return true;
				}

				var error_html = '<ol>';
				for (i = 0; i < errors.length; i++)
				{
					error_html += '<li>' + errors[i].firstChild.nodeValue + '</li>';
				}
				error_html += '</ol>';

				qr_show_errors('<ol>' + error_html + '</ol>');

				return false;
			}

			// this is the not so nice error handler, which is a fallback in case the previous one doesn't work
			qr_repost = true;
			fetch_object('qrform').submit();
		}
	}
	else
	{
		qr_repost = true;
		fetch_object('qrform').submit();
	}
}